@@ -8,8 +8,12 @@
 # email      : 2983997560@qq.com
 # Description：
 """
-import sys
 import os
+import sys
 import win32process
+from .thread import MyThread
+from .globalVar import global_info, thread_info
+from .publicFuc import register
+from .ld import *
 path = os.path.split(os.path.realpath(__file__))[0]
 sys.path.append(path)
