@@ -8,11 +8,13 @@
 # email      : 2983997560@qq.com
 # Description：全局变量封装
 """
-import win32com.client
-import time
-from random import uniform
-import win32com.client
 from .customVar import CustomE
+a = CustomE()
+
+
+def thread_info(num):
+    thread_list = [a]
+    return thread_list
 
 
 global_info = CustomE()
