@@ -15,10 +15,6 @@ class MyThread:
     def __init__(self, target=None, args=None, kwargs=None):
         pass
 
-    @classmethod
-    def init_com(cls, *args, **kwargs):
-        pass
-
     def pause(self, *args, **kwargs):
         pass
 
@@ -31,8 +27,4 @@ class MyThread:
     def stop(self, *args, **kwargs):
         pass
 
-    @classmethod
-    def uninstall_com(cls, *args, **kwargs):
-        pass
-
     handle = None
